/*-------------------------------------------------------------------------+
| Copyright 2012 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editor.annotations;

import java.util.ArrayList;
import java.util.Iterator;

import org.eclipse.jface.text.IRegion;
import org.eclipse.jface.text.ITextHover;
import org.eclipse.jface.text.ITextViewer;
import org.eclipse.jface.text.source.Annotation;
import org.eclipse.jface.text.source.AnnotationModel;
import org.eclipse.jface.text.source.IAnnotationHover;
import org.eclipse.jface.text.source.ISourceViewer;
import org.fortiss.tooling.base.ui.editor.annotations.ErrorAnnotation;

/**
 * Class acting as annotation hover manager.
 * 
 * @author doebber
 */
public class AnnotationHover implements IAnnotationHover, ITextHover {

	/** Stores the {@link AnnotationModel}. */
	private final AnnotationModel model;

	/** Constructor. */
	public AnnotationHover(AnnotationModel model) {
		this.model = model;
	}

	/** {@inheritDoc} */
	@Override
	public String getHoverInfo(ISourceViewer sourceViewer, int lineNumber) {
		Iterator<?> ite = model.getAnnotationIterator();

		ArrayList<String> all = new ArrayList<String>();

		while(ite.hasNext()) {
			Annotation a = (Annotation)ite.next();
			if(a instanceof ErrorAnnotation) {
				all.add(((ErrorAnnotation)a).getText());
			}
		}

		StringBuffer total = new StringBuffer();
		for(String str : all) {
			total.append(" " + str);// + "\n");
		}

		return total.toString();
	}

	/** {@inheritDoc} */
	@Override
	public String getHoverInfo(ITextViewer textViewer, IRegion hoverRegion) {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public IRegion getHoverRegion(ITextViewer textViewer, int offset) {
		return null;
	}
}
