/*-------------------------------------------------------------------------+
| Copyright 2020 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editor.fx.controller;

import static java.lang.Math.toRadians;
import static java.util.Objects.requireNonNull;
import static org.fortiss.tooling.base.ui.utils.LayoutDataUIUtils.setConnectorAngle;
import static org.fortiss.tooling.base.utils.LayoutDataUtils.getNodeSize;
import static org.fortiss.tooling.base.utils.LayoutDataUtils.moveNode;
import static org.fortiss.tooling.base.utils.LayoutDataUtils.setNodeSize;

import org.fortiss.tooling.base.model.element.IConnector;
import org.fortiss.tooling.base.model.layout.Dimension;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.common.ui.javafx.lwfxef.FeedbackChange;
import org.fortiss.tooling.common.ui.javafx.lwfxef.controller.IController;
import org.fortiss.tooling.common.ui.javafx.lwfxef.mvc.IContentAnchorageMVCBundle;
import org.fortiss.tooling.common.ui.javafx.lwfxef.mvc.IContentMVCBundle;
import org.fortiss.tooling.kernel.model.INamedCommentedElement;

/**
 * {@link IController} for {@link ILayoutedModelElement}s that have a elliptical shape.
 * 
 * @author munaro
 */
public class LayoutedEllipticResizableContentController<T extends ILayoutedModelElement & INamedCommentedElement>
		extends EObjectEllipticResizableContentControllerBase<T> {

	/** Constructor */
	public LayoutedEllipticResizableContentController(IContentMVCBundle mvcb, Class<T> modelType) {
		super(mvcb, modelType);

		Object model = requireNonNull(mvcb.getModel(), "The given model is null!");
		if(!modelType.isAssignableFrom(model.getClass())) {
			throw new IllegalArgumentException("Expected model of type " +
					modelType.getSimpleName() + ", but was " + model.getClass().getSimpleName());
		}
	}

	/** {@inheritDoc} */
	@Override
	protected void moveAnchorageToAngle(IContentAnchorageMVCBundle anchorage,
			double angleInDegree) {
		Object connObj = anchorage.getModel();
		if(connObj instanceof IConnector && connObj instanceof ILayoutedModelElement) {
			ILayoutedModelElement conn = (ILayoutedModelElement)connObj;
			setConnectorAngle(conn, toRadians(angleInDegree));
		}
	}

	/** {@inheritDoc} */
	@Override
	protected void move(FeedbackChange deltaChange) {
		moveNode(getModelElement(), (int)deltaChange.getDeltaX(), (int)deltaChange.getDeltaY());
	}

	/** {@inheritDoc} */
	@Override
	protected boolean allowLink() {
		return false;
	}

	/** {@inheritDoc} */
	@Override
	protected void resize(FeedbackChange delta) {
		T element = getModelElement();
		Dimension d = getNodeSize(element);
		int w = d.getWidth() + (int)delta.getDeltaW();
		int h = d.getHeight() + (int)delta.getDeltaH();
		setNodeSize(element, w, h);
	}
}
