/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.fortiss.tooling.common.ui.javafx.control.treetableview;

import javafx.scene.Node;
import javafx.scene.control.ContextMenu;
import javafx.scene.input.ClipboardContent;
import javafx.scene.input.Dragboard;

/**
 * This UI provider is responsible to return the label, the icon, and the context menu for each cell
 * in the {@link DynamicTreeViewer} based on the data object. It also handles drag start events.
 */
public abstract class DynamicTreeUIProviderBase<T> {
	/**
	 * @param element
	 *            the displayed element
	 * @return the label to be displayed
	 */
	public String getLabel(T element) {
		return "";
	}

	/**
	 * @param element
	 *            the displayed element
	 * @return the node to be displayed as the icon
	 */
	public Node getIconNode(T element) {
		return null;
	}

	/**
	 * @param element
	 *            the displayed element
	 * @return the context menu
	 */
	public ContextMenu createContextMenu(T element) {
		return null;
	}

	/**
	 * @param element
	 *            the tree element, which was dragged
	 * @return the content of the clipboard or {@code null} if the drag should be ignored.
	 */
	public ClipboardContent getDragClipboardContent(T element) {
		return null;
	}

	/**
	 * @param item
	 *            the tree element currently targeted by the drag location
	 * @param dragboard
	 *            the current {@link Dragboard}
	 * @return whether the drag-over event succeeds (i.e. should be consumed).
	 */
	public boolean dragOver(T item, Dragboard dragboard) {
		return false;
	}

	/**
	 * @param element
	 *            the element the content is dropped on
	 * @param dragboard
	 *            the current {@link Dragboard}
	 * @return whether the drop event completed (i.e. should be consumed).
	 */
	public boolean dropClipboardContent(T element, Dragboard dragboard) {
		return false;
	}
}
