/*-------------------------------------------------------------------------+
| Copyright 2019 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.common.ui.javafx.layout;

import java.util.List;

import javafx.fxml.FXML;
import javafx.scene.Node;

/**
 * Generic interface for JavaFX controllers which can be hierarchically composed.
 * 
 * @param <T>
 *            Type of the controlled element itself.
 * @param <S>
 *            Type of the layout elements which can be contained.
 * 
 * @author munaro
 */
public interface ICompositeFXController<T extends Node, S extends Node> {

	/** Loads the the JavaFX layout from the specified {@link FXML} resource. */
	public void loadLayout();

	/** Returns a {@link Node} with the layout. */
	public T getLayout();

	/** Returns the location of the {@link FXML} resource with the layout. */
	public String getFXMLLocation();

	/** Initializes the {@link ICompositeFXController}. */
	public void initialize();

	/** Returns the {@link ICompositeFXController} containments. */
	public List<ICompositeFXController<? extends S, ?>> getContainments();
}
