/*******************************************************************************
 * Copyright (c) 2019, 2020 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Apache License, Version 2.0 which is available at
 * https://www.apache.org/licenses/LICENSE-2.0.
 *
 * SPDX-License-Identifier: Apache-2.0
 *******************************************************************************/
package org.fortiss.tooling.common.ui.javafx.lwfxef;

import org.fortiss.tooling.common.ui.javafx.lwfxef.mvc.MVCBundleTag;

/**
 * Predefined {@link MVCBundleTag}s for focusing, selecting, hovering, link targeting, and
 * highlighting feedback.
 */
public final class DiagramViewerDefaultTags {
	/** The tagged bundle has the focus. */
	public static final MVCBundleTag FOCUS_TAG = makeTag("_FOCUS");
	/** The tagged bundle is the primary selection of the diagram viewer. */
	public static final MVCBundleTag PRIMARY_SELECTION_TAG = makeTag("_PRIMARY");
	/** The tagged bundle belongs to the secondary selections of the diagram viewer. */
	public static final MVCBundleTag SECONDARY_SELECTION_TAG = makeTag("_SECONDARY");
	/** The tagged bundle is currently hover over by the mouse pointer. */
	public static final MVCBundleTag HOVER_TAG = makeTag("_HOVER");
	/** The tagged bundle is a current link target. */
	public static final MVCBundleTag LINK_TARGET_ALLOWED_TAG = makeTag("_LINKTARGET_ALLOWED");
	/** The tagged bundle is not a current link target. */
	public static final MVCBundleTag LINK_TARGET_DENIED_TAG = makeTag("_LINKTARGET_DENIED");
	/** The tagged bundle might be a current link target. */
	public static final MVCBundleTag LINK_TARGET_MAYBE_TAG = makeTag("_LINKTARGET_MAYBE");
	/** The tagged bundle is highlighted as incoming link */
	public static final MVCBundleTag HIGHLIGHT_INCOMING_LINK_TAG =
			makeTag("_HIGHLIGHT_INCOMING_LINK");
	/** The tagged bundle is highlighted as outgoing link */
	public static final MVCBundleTag HIGHLIGHT_OUTGOING_LINK_TAG =
			makeTag("_HIGHLIGHT_OUTGOING_LINK");

	/** Creates the tag. */
	private static MVCBundleTag makeTag(String tagId) {
		return new MVCBundleTag(DiagramViewerDefaultTags.class, tagId);
	}
}
