/*******************************************************************************
 * Copyright (c) 2019, 2020 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Apache License, Version 2.0 which is available at
 * https://www.apache.org/licenses/LICENSE-2.0.
 *
 * SPDX-License-Identifier: Apache-2.0
 *******************************************************************************/
package org.fortiss.tooling.common.ui.javafx.lwfxef.controller;

import org.fortiss.tooling.common.ui.javafx.lwfxef.DiagramViewer;
import org.fortiss.tooling.common.ui.javafx.lwfxef.mvc.IContentAnchorageMVCBundle;
import org.fortiss.tooling.common.ui.javafx.lwfxef.mvc.IContentMVCBundle;
import org.fortiss.tooling.common.ui.javafx.lwfxef.mvc.IDiagramAnchorageMVCBundle;
import org.fortiss.tooling.common.ui.javafx.lwfxef.mvc.IDiagramMVCBundle;
import org.fortiss.tooling.common.ui.javafx.lwfxef.mvc.ILinkMVCBundle;

/**
 * Interface for factories which create controllers for model elements in a {@link DiagramViewer}.
 */
public interface IControllerFactory {
	/** Returns the controller instance for the given content model. */
	IController createContentController(IContentMVCBundle model);

	/** Returns the controller instance for the given diagram anchorage model. */
	IController createDiagramAnchorageController(IDiagramAnchorageMVCBundle modelBundle);

	/**
	 * Returns the controller instance for the given content anchorage model. Sub-classes may assume
	 * that {@code model.getAttachedTo()} points to the parent {@link IContentMVCBundle}.
	 */
	IController createContentAnchorageController(IContentAnchorageMVCBundle modelBundle);

	/**
	 * Returns the controller instance for the given link model. Sub-classes may assume that
	 * {@code modelBundle.getAttachedTo()} points to the parent {@link IDiagramMVCBundle}.
	 */
	IController createLinkController(ILinkMVCBundle modelBundle);

	/**
	 * Returns the controller instance for the given diagram bundle. This method is called only once
	 * when the diagram is initialized.
	 */
	IController createDiagramController(IDiagramMVCBundle diagramBundle);
}
