/*******************************************************************************
 * Copyright (c) 2019, 2020 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Apache License, Version 2.0 which is available at
 * https://www.apache.org/licenses/LICENSE-2.0.
 *
 * SPDX-License-Identifier: Apache-2.0
 *******************************************************************************/
package org.fortiss.tooling.common.ui.javafx.lwfxef.controller;

import org.fortiss.tooling.common.ui.javafx.lwfxef.DiagramCoordinate;
import org.fortiss.tooling.common.ui.javafx.lwfxef.change.Change;
import org.fortiss.tooling.common.ui.javafx.lwfxef.mvc.IMVCBundle;

import javafx.scene.Node;

/** Interface for controllers, which handle standard drag gestures provided by the visuals. */
public interface IDragController {
	/**
	 * Informs the drag controller that the drag gesture has started on the given bundle, node and
	 * diagram location.
	 */
	void dragStarted(IMVCBundle startBundle, Node startNode, DiagramCoordinate lastMouseLocation);

	/** Updates the drag controller with the new drag bundle, node, and diagram location. */
	void dragInProgress(IMVCBundle currentBundle, Node currentNode,
			DiagramCoordinate lastMouseLocation);

	/**
	 * Informs the drag controller about the final result: the target bundle, target node and
	 * diagram location. This operation may result in a {@link Change} to the underlying model.
	 */
	Change dragCompleted(IMVCBundle endBundle, Node endNode, DiagramCoordinate lastMouseLocation);
}
