/*******************************************************************************
 * Copyright (c) 2019, 2020 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Apache License, Version 2.0 which is available at
 * https://www.apache.org/licenses/LICENSE-2.0.
 *
 * SPDX-License-Identifier: Apache-2.0
 *******************************************************************************/
package org.fortiss.tooling.common.ui.javafx.lwfxef.controller.elliptic;

import static org.fortiss.tooling.common.ui.javafx.lwfxef.visual.elliptic.EllipticBorderLocation.getClosestLocationOnBounds;

import org.fortiss.tooling.common.ui.javafx.lwfxef.DiagramCoordinate;
import org.fortiss.tooling.common.ui.javafx.lwfxef.controller.IDragController;
import org.fortiss.tooling.common.ui.javafx.lwfxef.controller.base.AnchorageContentControllerBase;
import org.fortiss.tooling.common.ui.javafx.lwfxef.controller.base.ContentAnchorageMoveControllerBase;
import org.fortiss.tooling.common.ui.javafx.lwfxef.mvc.IContentAnchorageMVCBundle;
import org.fortiss.tooling.common.ui.javafx.lwfxef.mvc.IContentMVCBundle;
import org.fortiss.tooling.common.ui.javafx.lwfxef.visual.elliptic.EllipticBorderLocation;

import javafx.geometry.Dimension2D;
import javafx.geometry.Point2D;
import javafx.geometry.Rectangle2D;

/** Base class for controllers with content visuals represented by ellipses. */
public abstract class CircularResizableContentControllerBase
		extends AnchorageContentControllerBase {
	/** Constructor. */
	public CircularResizableContentControllerBase(IContentMVCBundle mvcb) {
		super(mvcb);
	}

	/** {@inheritDoc} */
	@Override
	protected IDragController createAnchorageMoveController(IContentAnchorageMVCBundle anchorage) {
		return new CircularAnchorageMoveController(anchorage);
	}

	/** Move controller for anchorages moving on the ellipse border. */
	private final class CircularAnchorageMoveController extends ContentAnchorageMoveControllerBase {
		/** Constructor. */
		public CircularAnchorageMoveController(IContentAnchorageMVCBundle anchorage) {
			super(anchorage);
		}

		/** Returns the border location on the ellipse shape. */
		private EllipticBorderLocation getBorderLocation(DiagramCoordinate delta) {
			Rectangle2D contentBounds = getVisual().getModelBounds();
			Rectangle2D anchorageBounds = anchorage.getVisual().getModelBounds();
			Dimension2D span =
					new Dimension2D(anchorageBounds.getWidth(), anchorageBounds.getHeight());
			Point2D p = new Point2D(anchorageBounds.getMinX() + delta.getX(),
					anchorageBounds.getMinY() + delta.getY());
			EllipticBorderLocation rbl = getClosestLocationOnBounds(p, contentBounds, span);
			return rbl;
		}

		/** {@inheritDoc} */
		@Override
		protected Point2D getAnchorageFeedbackLocation(DiagramCoordinate delta) {
			EllipticBorderLocation rbl = getBorderLocation(delta);
			return rbl.getLocation();
		}

		/** {@inheritDoc} */
		@Override
		protected void moveAnchorage(DiagramCoordinate delta) {
			EllipticBorderLocation rbl = getBorderLocation(delta);
			moveAnchorageToAngle(anchorage, rbl.getAngleInDegree());
		}
	}

	/** Sets the angle of the given anchorage when move operation has completed. */
	protected abstract void moveAnchorageToAngle(IContentAnchorageMVCBundle anchorage,
			double angleInDegree);
}
