/*******************************************************************************
 * Copyright (c) 2019, 2020 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Apache License, Version 2.0 which is available at
 * https://www.apache.org/licenses/LICENSE-2.0.
 *
 * SPDX-License-Identifier: Apache-2.0
 *******************************************************************************/
package org.fortiss.tooling.common.ui.javafx.lwfxef.controller.rectangular;

import static org.fortiss.tooling.common.ui.javafx.lwfxef.visual.rectangular.RectangularBorderLocation.getClosestLocationOnBounds;

import org.fortiss.tooling.common.ui.javafx.lwfxef.DiagramCoordinate;
import org.fortiss.tooling.common.ui.javafx.lwfxef.controller.base.ContentAnchorageMoveControllerBase;
import org.fortiss.tooling.common.ui.javafx.lwfxef.mvc.IContentAnchorageMVCBundle;
import org.fortiss.tooling.common.ui.javafx.lwfxef.visual.rectangular.RectangularBorderLocation;

import javafx.geometry.Dimension2D;
import javafx.geometry.Point2D;
import javafx.geometry.Rectangle2D;

/**
 * Default implementation for moving content anchorages on the border of a rectangular content
 * model element visual.
 */
public class RectangularContentAnchorageMoveController extends ContentAnchorageMoveControllerBase {
	/** The controller of the rectangular content visual. */
	private final RectangularResizableContentControllerBase contentController;

	/** Constructor. */
	public RectangularContentAnchorageMoveController(
			RectangularResizableContentControllerBase controller,
			IContentAnchorageMVCBundle anchorage) {
		super(anchorage);
		this.contentController = controller;
	}

	/** Returns the location clamped to the border of the parent visual. */
	private RectangularBorderLocation getLocationOnBorder(IContentAnchorageMVCBundle anchorage,
			Point2D delta) {
		Rectangle2D contentBounds = contentController.getVisual().getModelBounds();
		Rectangle2D anchorageBounds = anchorage.getVisual().getModelBounds();
		Dimension2D anchorageSize =
				new Dimension2D(anchorageBounds.getWidth(), anchorageBounds.getHeight());
		Dimension2D borderSnap = overrideBorderSnap(anchorageSize);
		DiagramCoordinate p = new DiagramCoordinate(
				anchorageBounds.getMinX() + anchorageSize.getWidth() / 2 + delta.getX(),
				anchorageBounds.getMinY() + anchorageSize.getHeight() / 2 + delta.getY());
		return getClosestLocationOnBounds(p, contentBounds, anchorageSize, borderSnap);
	}

	/** Allows sub-classes to override the default span calculation. */
	protected Dimension2D overrideBorderSnap(Dimension2D anchorageBounds) {
		return anchorageBounds;
	}

	/** {@inheritDoc} */
	@Override
	protected Point2D getAnchorageFeedbackLocation(DiagramCoordinate delta) {
		RectangularBorderLocation rbl = getLocationOnBorder(anchorage, delta);
		return rbl.getLocation();
	}

	/** {@inheritDoc} */
	@Override
	protected void moveAnchorage(DiagramCoordinate delta) {
		RectangularBorderLocation rbl = getLocationOnBorder(anchorage, delta);
		contentController.moveAnchorageToSideOffset(anchorage, rbl.getSide(), rbl.getOffset());
	}
}
