/*******************************************************************************
 * Copyright (c) 2019, 2020 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Apache License, Version 2.0 which is available at
 * https://www.apache.org/licenses/LICENSE-2.0.
 *
 * SPDX-License-Identifier: Apache-2.0
 *******************************************************************************/
package org.fortiss.tooling.common.ui.javafx.lwfxef.visual;

import org.fortiss.tooling.common.ui.javafx.lwfxef.model.layout.ILayout;

/** Interface for anchorage visuals which stick to a content node in the diagram. */
public interface IContentAnchorageVisual extends IAnchorageVisual {
	/**
	 * Returns the layout information for this content anchorage. Callers must provide an actual
	 * type of the requested layout information.
	 */
	<T extends ILayout> T getLayout(Class<T> type);

	/**
	 * Returns whether sibling anchorage visuals (i.e. those attached to the same content visual as
	 * this anchorage visual) should be updated when this visual is hovered over by the mouse
	 * pointer. The default is {@code false}.
	 * 
	 * @see IContentVisual#updateAttachedAnchorageVisualsOnHover()
	 */
	boolean updateSiblingAnchorageVisualsOnHover();
}
