/*******************************************************************************
 * Copyright (c) 2019, 2020 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Apache License, Version 2.0 which is available at
 * https://www.apache.org/licenses/LICENSE-2.0.
 *
 * SPDX-License-Identifier: Apache-2.0
 *******************************************************************************/
package org.fortiss.tooling.common.ui.javafx.lwfxef.visual.base;

import org.fortiss.tooling.common.ui.javafx.lwfxef.FeedbackChange;
import org.fortiss.tooling.common.ui.javafx.lwfxef.mvc.IDiagramAnchorageMVCBundle;
import org.fortiss.tooling.common.ui.javafx.lwfxef.visual.IDiagramAnchorageVisual;

import javafx.geometry.Rectangle2D;
import javafx.scene.paint.Color;
import javafx.scene.paint.Paint;
import javafx.scene.shape.Shape;

/** Base implementation of {@link IDiagramAnchorageVisual}. */
public abstract class DiagramAnchorageVisualBase extends VisualBase
		implements IDiagramAnchorageVisual {
	/** Constructor. */
	public DiagramAnchorageVisualBase(IDiagramAnchorageMVCBundle mvcb, Shape visual, Shape hit) {
		super(mvcb, visual, hit);
	}

	/** {@inheritDoc} */
	@Override
	public IDiagramAnchorageMVCBundle getMVCBundle() {
		// wild cast works: see constructor
		return (IDiagramAnchorageMVCBundle)super.getMVCBundle();
	}

	/** {@inheritDoc} */
	@Override
	public Rectangle2D getCurrentBounds() {
		FeedbackChange fb = getMVCBundle().getFeedbackChange();
		Rectangle2D mb = getModelBounds();
		return fb.applyTo(mb);
	}

	/** Returns the color to be used when the port is highlighted as incoming port. */
	protected Paint getHighlightIncomingLinkColor() {
		return Color.GREENYELLOW;
	}

	/** Returns the color to be used when the port is highlighted as outgoing port. */
	protected Paint getHighlightOutgoingLinkColor() {
		return Color.TOMATO;
	}

	/** Returns the color of the border to be used when the port is highlighted as incoming port. */
	protected Paint getHighlightIncomingLinkBorderColor() {
		return Color.GREENYELLOW.darker();
	}

	/** Returns the color of the border to be used when the port is highlighted as outgoing port. */
	protected Paint getHighlightOutgoingLinkBorderColor() {
		return Color.TOMATO.darker();
	}
}
