/*******************************************************************************
 * Copyright (c) 2017, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Apache License, Version 2.0, which is available at 
 * https://www.apache.org/licenses/LICENSE-2.0.
 *
 * SPDX-License-Identifier: Apache-2.0
 *******************************************************************************/
package org.fortiss.tooling.common.ui.javafx.style;

import javafx.scene.canvas.GraphicsContext;
import javafx.scene.paint.Color;

/**
 * Represents a style to be used in for filling areas.
 * 
 * @author hoelzl
 */
public final class FillStyle extends ColorStyleBase {
	/** Alpha transparency value (default is opaque 1.0). */
	private final double alpha;

	/** Constructor */
	public FillStyle(Color rgbColor) {
		this(rgbColor, 1);
	}

	/** Constructor */
	public FillStyle(Color c, double alpha) {
		super(new Color(c.getRed(), c.getGreen(), c.getBlue(), alpha));
		this.alpha = alpha;
	}

	/** Returns alpha value. */
	public double getAlpha() {
		return alpha;
	}

	/** Applies the style to the given graphics context. */
	public void applyStyle(GraphicsContext gc) {
		gc.setFill(getColor());
	}
}
