/*******************************************************************************
 * Copyright (c) 2017, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Apache License, Version 2.0, which is available at 
 * https://www.apache.org/licenses/LICENSE-2.0.
 *
 * SPDX-License-Identifier: Apache-2.0
 *******************************************************************************/
package org.fortiss.tooling.common.ui.javafx.style;

import javafx.scene.canvas.GraphicsContext;

/**
 * Represents the style of the stroke of a line.
 * 
 * @author hoelzl
 */
public final class StrokeStyle {
	/** Stroke style of the solid line. */
	public static final StrokeStyle SOLID = new StrokeStyle(0, null);
	/** The line dash offset. */
	private final double offset;
	/** The dashes array. */
	private final double[] dashes;

	/** Constructor. */
	public StrokeStyle(double offset, double[] dashes) {
		this.offset = offset;
		this.dashes = dashes;
	}

	/** Set the stroke style for the given graphics context. */
	public void applyStyle(GraphicsContext gc) {
		gc.setLineDashOffset(offset);
		gc.setLineDashes(dashes);
	}
}
