/*-------------------------------------------------------------------------+
| Copyright 2020 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension;

/**
 * Defines an entry point to process command line arguments following a switch. Each implementing
 * class must be accompanied with an extension point definition that defines the (string) identifier
 * of the switch. The registered classes are executed after all services are started.
 * 
 * @author diewald
 */
public interface ICommandLineSwitchHandler {

	/** Indicates whether the handler expects an additional argument after the registered switch. */
	boolean hasAdditionalArgument();

	/**
	 * Entry point to handle the given {@code argument} given at the command line.
	 * 
	 * @param argument
	 *            String argument following a switch's identifier .
	 */
	void handleCLISwitch(String argument);
}
