/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension;

import java.util.List;

import org.fortiss.tooling.kernel.extension.data.ModelStorageError;
import org.fortiss.tooling.kernel.extension.data.ITopLevelElement;

/**
 * An {@link IStorageProvider} implements a storage mechanism for EMF models. A
 * storage provider must deliver an {@link ITopLevelElement} for each model
 * under his supervision. It may rely on other parts of the Eclipse workbench
 * like the Team feature or EMFStore providing remote storage capability. After
 * the context was provided to the kernel it invokes the methods of the context
 * to execute commands, save, an so on.
 * <P>
 * The {@link IStorageProvider} may report out-dated models (e.g. due to meta-model changes) to the
 * kernel with the {@link #getStorageErrors()} method.
 * 
 * <P>
 * By default, the kernel uses the Eclipse workspace resources and XML-based file storage. See
 * {@link IEclipseResourceStorageLocationProvider} for this persistency solution.
 * 
 * @author hoelzl
 */
public interface IStorageProvider {

	/**
	 * Returns the top-level elements provided by this storage provider. This
	 * method is called by persistency service during initialization. Only
	 * successfully loaded models must be returned to the persitency service.
	 */
	List<ITopLevelElement> getTopLevelElements();

	/** Returns the list of storage errors. */
	List<ModelStorageError> getStorageErrors();
}
