/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.service;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.extension.IConstraintChecker;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation.ESeverity;
import org.fortiss.tooling.kernel.internal.ConstraintCheckerService;

/**
 * The constraint service manages registration and execution of model element
 * constraints.
 * 
 * @see IConstraintChecker
 * 
 * @author hoelzl
 */
public interface IConstraintCheckerService {
	/** Returns the service instance. */
	public static IConstraintCheckerService getInstance() {
		return ConstraintCheckerService.getInstance();
	}

	/**
	 * Performs all constraint checks on the given model element and recursively
	 * its content and returns the check results. Note, that this method can be
	 * time-consuming for large model element trees.
	 * <P>
	 * The returned list is ordered according to {@link ESeverity} from FATAL to DEBUG.
	 */
	List<IConstraintViolation<? extends EObject>>
			performAllConstraintChecksRecursively(EObject modelElement);

	/**
	 * Performs all constraint checks only on the given model element and
	 * returns the check results.
	 * <P>
	 * The returned list is ordered according to {@link ESeverity} from FATAL to DEBUG.
	 */
	List<IConstraintViolation<? extends EObject>> performAllConstraintChecks(EObject modelElement);

	/**
	 * Returns the list of registered constraint checkers for the given model
	 * element.
	 */
	List<IConstraintChecker<? extends EObject>> getAllConstraintCheckers(EObject modelElement);

	/** Registers the given checker with the service. */
	void registerConstraintChecker(IConstraintChecker<EObject> checker, Class<?> modelElementClass);
}
