/*******************************************************************************
 * Copyright (c) 2017, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Apache License, Version 2.0, which is available at 
 * https://www.apache.org/licenses/LICENSE-2.0.
 *
 * SPDX-License-Identifier: Apache-2.0
 *******************************************************************************/
package org.fortiss.tooling.spiderchart.model;

import static java.util.Objects.requireNonNull;

import java.util.HashMap;
import java.util.Map;

/**
 * Class representing series of data for each axis of a spider chart.
 * 
 * @author hoelzl
 */
public final class DataSeries {
	/** The name of the data series. */
	private String name;
	/** The points for each axis. */
	private Map<AxisBase, Object> points = new HashMap<AxisBase, Object>();

	/** Constructor. */
	public DataSeries(String name) {
		setName(name);
	}

	/** Sets name. */
	public void setName(String name) {
		this.name = requireNonNull(name);
	}

	/** Returns name. */
	public String getName() {
		return name;
	}

	/** Sets the point for the given axis. */
	public <T extends Object> void setPoint(AxisBase axis, T value) {
		points.put(requireNonNull(axis), requireNonNull(value));
	}

	/** Returns the point for the given axis. */
	public Object getAxisValue(AxisBase a) {
		return points.get(a);
	}
}
