/*******************************************************************************
 * Copyright (c) 2017, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Apache License, Version 2.0, which is available at 
 * https://www.apache.org/licenses/LICENSE-2.0.
 *
 * SPDX-License-Identifier: Apache-2.0
 *******************************************************************************/
package org.fortiss.tooling.spiderchart.model;

import java.util.Comparator;

/**
 * Class representing an axis of the spider chart displaying double values.
 * 
 * @author hoelzl
 */
public final class DoubleAxis extends AxisBase {
	/** The minimum value of the axis (at the center of the spider chart). */
	private Double minimumValue = 0.0;
	/** The maximum value of this axis. */
	private Double maximumValue = 1.0;

	/** Constructor. */
	public DoubleAxis(Double min, Double max) {
		this("", min, max);
	}

	/** Constructor. */
	public DoubleAxis(String name, Double min, Double max) {
		super(name);
		this.minimumValue = min;
		this.maximumValue = max;
	}

	/** Returns minimum value. */
	public Double getMinimumValue() {
		return minimumValue;
	}

	/** Returns maximum value. */
	public Double getMaximumValue() {
		return maximumValue;
	}

	/** Returns the value for the given ratio of this axis. */
	public Double getAxisValue(Double ratio) {
		Double length = maximumValue - minimumValue;
		return minimumValue + ratio * length;
	}

	/** Returns the ratio for the given value. */
	public Double getAxisRatio(Double value) {
		return (value - minimumValue) / (maximumValue - minimumValue);
	}

	/** Public comparator for value of DoubleAxis. */
	public static final Comparator<Double> DOUBLE_COMPARATOR = new Comparator<Double>() {
		@Override
		public int compare(Double o1, Double o2) {
			double delta = o1 - o2;
			if(delta < 0.0) {
				return -1;
			} else if(delta > 0.0) {
				return 1;
			}
			return 0;
		}
	};

	/** {@inheritDoc} */
	@Override
	public boolean isValidValue(Object o) {
		Double d = (Double)o;
		return minimumValue <= d && d <= maximumValue;
	}
}
